﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSV µW Frequency Response Test /4418,SWPG
DATE:                  2011-07-29
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       153
CONFIGURATION:         Agilent E4418B
CONFIGURATION:         HP 8481A on channel 1
CONFIGURATION:         Sweep Generator
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Rohde & Schwarz FSV series > 3.6 GHz, <= 13 GHz
#
#  Compatibility:
#        MET/CAL 7.3 SP1 (7.3.36) or later
#
#  Subprocedures:
#        Sub Apply /SWPG
#        Sub FSV Take Sweep (MKPK)
#        Sub FSV Set Ref Level (dBm) /SWPG
#        Sub Compute Power Splitter Leveling Uncertainty
#
#  Required Files:
#        None
#
#  Flexible Standard(s) Required:
#        Synthesized Sweep Generator (SWPG):
#          Frequency Range: 10 MHz to 13 GHz, CW
#            Accuracy: Locked to 10 MHz External Reference (UUT)
#
#          Amplitude Range: -45 to -5 dBm
#            Accuracy: ±2 dB
#
#  Additional Equipment Required:
#        None
#
#  Example:
# 1.001  MATH         @TestFreq = 3.61E+9
# 1.002  CALL         Sub FSV µW Frequency Response Test /4418,SWPG
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
# M4418 statement to allow procedure to compile.
  1.002  M4418  F64   8481A
  1.003  IEEE         [@SWPG]
  1.004  ENDIF

  1.005  MATH         Freq = (@TestFreq / 1E+9) & " GHz"
  1.006  MATH         Type = @AttenType; Attn = @Atten; Cpl = @Coupling

  1.007  HEAD         -2 Frequency: [V Freq], [V Type]: [V Attn] dB [V Cpl]
  1.008  SCPI         FREQ:SPAN?[I]

# Determine tolerance based on full span, or preamp on/off and attenuation.
  1.009  IF           (MEM > 7E+9)
  1.010  TOL          2.500U
  1.011  ELSEIF       (MEM > 13.6E+9)
  1.012  TOL          3.000U
  1.013  ELSEIF       (MEM > 30E+9)
  1.014  TOL          3.500U

  1.015  ELSEIF       ISVAR("@PreampOn")

  1.016  IF           (@TestFreq > 7E+9)
  1.017  TOL          3.000U
  1.018  ELSEIF       (@TestFreq > 13.6E+9)
  1.019  TOL          3.500U
  1.020  ELSE
  1.021  TOL          4.000U
  1.022  ENDIF

  1.023  ELSE         ; (NOT(ISVAR("@PreampOn"))

  1.024  IF           (@Atten < 10)

  1.025  IF           (@TestFreq > 7E+9)
  1.026  TOL          2.500U
  1.027  ELSEIF       (@TestFreq > 13.6E+9)
  1.028  TOL          3.000U
  1.029  ELSE
  1.030  TOL          3.500U
  1.031  ENDIF

  1.032  ELSE

  1.033  IF           (@TestFreq > 7E+9)
  1.034  TOL          1.500U
  1.035  ELSEIF       (@TestFreq > 13.6E+9)
  1.036  TOL          2.000U
  1.037  ELSE
  1.038  TOL          2.500U
  1.039  ENDIF

  1.040  ENDIF

  1.041  ENDIF

  1.042  TARGET       -p
  1.043  TSET         TDESC = [32][V Freq]
  1.044  SCPI         FREQ:CENT [V @TestFreq]
  1.045  MATH         @SWPG_Freq = @TestFreq & "Hz"
  1.046  CALL         Sub Apply /SWPG
  1.047  TARGET       -m
  1.048  CALL         Sub FSV Take Sweep (MKPK)
  1.049  SCPI         CALC:MARK:Y?[I]
  1.050  CALL         Sub FSV Set Ref Level (dBm) /SWPG
  1.051  MATH         MEM = @TestFreq
# Set NOMINAL value to -25 dBm for compatibility with low-level test.
  1.052  4418         -25.00D                      H                 RF N  CH1
# Store measured value elsewhere since MEM is overwritten in subsequent sub.
  1.053  MATH         @FreqResp = MEM - @RefPower

  1.054  IF           (@Atten < 10)
  1.055  MATH         @UUT_SWR = 2.5
  1.056  ELSE
  1.057  MATH         @UUT_SWR = 2.0
  1.058  ENDIF

  1.059  CALL         Sub Compute Power Splitter Leveling Uncertainty

# 8481A cal factor uncertainties (percent) taken from Agilent data sheet.
  1.060  IF           (@TestFreq > 500E+6)
  1.061  MATH         @LevelUncPct = RSS2(@LevelUncPct, (0.78 / 2))
  1.062  ELSEIF       (@TestFreq > 1.2E+9)
  1.063  MATH         @LevelUncPct = RSS2(@LevelUncPct, (0.92 / 2))
  1.064  ELSEIF       (@TestFreq > 6E+9)
  1.065  MATH         @LevelUncPct = RSS2(@LevelUncPct, (1.16 / 2))
  1.066  ELSEIF       (@TestFreq > 14E+9)
  1.067  MATH         @LevelUncPct = RSS2(@LevelUncPct, (1.59 / 2))
  1.068  ENDIF

# Combine and expand uncertainties; convert from linear to log (delta).
  1.069  MATH         L[1] = PCTTODBW_D(RSS2(@LevelUncPct, @RefUncPct) * 2)
#v Retrieve measured value for evaluation.
  1.070  MATH         MEM = @FreqResp
  1.071  ACC          0.00dB         L1U
  1.072  MEMCX        0.00dB         TOL

  2.001  END
